@@ -11,7 +11,7 @@ from montecarlodata.integrations.onboarding.fields import GQL_TO_FRIENDLY_CONNEC
 
 
 class OnboardingStatusService:
-    _INTEGRATION_FRIENDLY_HEADERS = ['Integration', 'ID', 'Connection', 'Created on (UTC)']
+    _INTEGRATION_FRIENDLY_HEADERS = ['Integration', 'Name', 'ID', 'Connection', 'Created on (UTC)']
 
     def __init__(self, config: Config, user_service: Optional[UserService] = None):
         self._abort_on_error = True
@@ -21,23 +21,24 @@ class OnboardingStatusService:
     def display_integrations(self, headers: Optional[str] = 'firstrow', table_format: Optional[str] = 'fancy_grid'):
         """
         Display active integrations in an easy to read table. E.g.
-        ╒══════════════════╤══════════════════════════════════════╤══════════════════════════════════╕
-        │ Integration      │ ID                                   │ Created on (UTC)                 │
-        ╞══════════════════╪══════════════════════════════════════╪══════════════════════════════════╡
-        │ Hive (metastore) │ 1023721b-e639-44ed-9838-e1f669d3fc85 │ 2020-05-09T01:49:52.806602+00:00 │
-        ╘══════════════════╧══════════════════════════════════════╧══════════════════════════════════╛
+        ╒═══════════════════╤═══════════╤══════════════════════════════════════╤═════════════════════════════╤══════════════════════════════════╕
+        │ Integration       │ Name      │ ID                                   │ Connection                  │ Created on (UTC)                 │
+        ╞═══════════════════╪═══════════╪══════════════════════════════════════╪═════════════════════════════╪══════════════════════════════════╡
+        │ Snowflake         │ rick_test │ 9403e385-1a56-4c3b-b185-4f2bb8e324d3 │ account: hda34492.us-east-1 │ 2022-03-25T19:55:11.858022+00:00 │
+        ╘═══════════════════╧═══════════╧══════════════════════════════════════╧═════════════════════════════╧══════════════════════════════════╛
         """
         table = [self._INTEGRATION_FRIENDLY_HEADERS]
         for integration in (self._user_service.warehouses or [{}]) + (self._user_service.bi_containers or [{}]):
-            table += self._build_table_record(connections=integration.get('connections'))
+            table += self._build_table_record(name=integration.get('name'), connections=integration.get('connections'))
         click.echo(tabulate(table, headers=headers, tablefmt=table_format))
 
-    def _build_table_record(self, connections: List[Dict]) -> List[List[str]]:
+    def _build_table_record(self, name: str, connections: List[Dict]) -> List[List[str]]:
         table = []
         for connection in connections or []:
             table.append(
                 [
                     GQL_TO_FRIENDLY_CONNECTION_MAP.get(normalize_gql(connection['type']), connection['type']),
+                    name,
                     connection['uuid'],
                     self._build_connection_info(connection),
                     connection['createdOn']
