@@ -52,6 +52,8 @@ query getUser {
         stackArn
         active
         customerAwsAccountId
+        templateProvider
+        templateVariant
         templateVersion
         codeVersion
         lastUpdated
